Return function to subset a user provided colour palette
Value
A function that takes the number of colours required and returns a character vector of that many hex colours from the palette.
Examples
pois_pal_custom(c("#1E6091", "#D9ED92", "#99D98C"))(3)
#> [1] "#1E6091" "#D9ED92" "#99D98C"